@@ -30,6 +30,15 @@
 class QTemporaryFile;
 class QFileDevice;
 
+/**
+ * SVN commands execution results.
+ */
+struct CommandResult {
+    bool success;       ///< True if return code is '0' (normal execution).
+    QString stdout;     ///< Process stdout.
+    QString stderr;     ///< Process stderr.
+};
+
 /**
  * Path information for log entry.
  */
@@ -112,17 +121,26 @@ public:
     static QString remoteRelativeUrl(const QString& filePath);
 
     /**
-     * Updates selected \p filePath to revision \p revision. \p filePath could be a sigle file or a
+     * From file \p filePath returns full working copy root path this file contains.
+     *
+     * \return Full local working copy root path, empty QString in case of error.
+     *
+     * \note This function uses only local SVN data without connection to a remote so it's fast.
+     */
+    static QString localRoot(const QString& filePath);
+
+    /**
+     * Updates selected \p filePath to revision \p revision. \p filePath could be a single file or a
      * directory. It also could be an absolute or relative.
      *
      * \return True on success, false either.
      *
-     * \note This function uses only local SVN data without connection to a remote so it's fast.
+     * \note This function can be really time consuming.
      */
     static bool updateToRevision(const QString& filePath, ulong revision);
 
     /**
-     * Discards all local changes in a \p filePath. \p filePath could be a sigle file or a directory.
+     * Discards all local changes in a \p filePath. \p filePath could be a single file or a directory.
      * It also could be an absolute or relative.
      *
      * \return True on success, false either.
@@ -132,13 +150,22 @@ public:
     static bool revertLocalChanges(const QString& filePath);
 
     /**
-     * Reverts selected \p filePath to revision \p revision. \p filePath could be a sigle file or a
+     * Reverts selected \p filePath to revision \p revision. \p filePath could be a single file or a
      * directory. It also could be an absolute or relative.
      *
      * \return True on success, false either.
      */
     static bool revertToRevision(const QString& filePath, ulong revision);
 
+    /**
+     * Runs 'svn cleanup' on a \p dir to remove write locks, resume unfinished operations, etc. Its
+     * restores directory state if Subversion client has crushed.
+     * Also this command could be used to remove unversioned or ignored files.
+     *
+     * \return Filled up \p commandResult structure.
+     */
+    static CommandResult cleanup(const QString& dir, bool removeUnversioned = false, bool removeIgnored = false, bool includeExternals = false);
+
     /**
      * Export URL \p path at revision \p rev to a file \p file. URL could be a remote URL to a file
      * or directory or path to a local file or directory (both relative or absolute). File should
@@ -156,11 +183,21 @@ public:
      * absolute paths accepted). Log starts from revision \p fromRevision and goes for \p maxEntries
      * previous revisions. The default revision (0) means current revision.
      *
-     * \return Full log, empty QVector in case of error.
+     * \return Full log, nullptr in case of error.
      *
      * \note This function is really time consuming.
      */
     static QSharedPointer< QVector<logEntry> > getLog(const QString& filePath, uint maxEntries = 255, ulong fromRevision = 0);
+
+    /**
+     * Check out a working copy of repository \p URL (local URL starts with a 'file://') to a local
+     * path \p whereto (could be relative ot absolute).
+     *
+     * \return True if check out success, false either.
+     *
+     * \note This function can be really time consuming.
+     */
+    static bool checkoutRepository(const QString& url, bool ignoreExternals, const QString& whereto);
 };
 
 #endif  // SVNCOMMANDS_H
